v0.2.1 (February 21, 2021)
==========================
  * DEP: Loosen dependency requirements (#46)
  * DOC: Add groupyr/group-lasso comparison example (#44)
  * Move matplotlib dependency to dev option (#45)
  * DOC: Add author contributions using the CRediT taxonomy (#42)
  * DOC: Add help target to makefile to make is self-documenting (#43)
  * ENH: Add lightning and group-lasso citations to paper (#41)
  * DEP: remove ipywidgets from setup.cfg dependencies (#40)
  * Remove redundant paper reference (#38)

